@@ -20,8 +20,8 @@ class SerialInterface(BaseInterface):
     
     
     @classmethod
-    def new_args(cls, parent, config):
-        d = super().new_args(parent, config)
+    def new_args(cls, parent, name, config):
+        d = super().new_args(parent, name, config)
         d.update(com=parent.com)
         return d
 
